@@ -72,10 +72,19 @@ static inline int my_kernel_read(struct file *file, unsigned long offset,
 	return result;
 #elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 14, 0)
 	return kernel_read(file, offset, addr, count);
-#else
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(5, 10, 0)
 	loff_t pos = offset;
 
 	return kernel_read(file, addr, count, &pos);
+#else
+	struct kvec iov = { .iov_base = addr, .iov_len = count };
+	struct kiocb kiocb;
+	struct iov_iter iter;
+
+	init_sync_kiocb(&kiocb, file);
+	iov_iter_kvec(&iter, READ, &iov, 1, count);
+	kiocb.ki_pos = offset;
+	return seq_read_iter(&kiocb, &iter);
 #endif
 }
 
@@ -486,7 +495,7 @@ static void * __init probe_find_variable(void *function, unsigned long addr,
 	return probe_find_vfsmount_lock_on_arm(function, addr,
 					       (unsigned int *) base);
 #endif
-	/* First, assume absolute adressing mode is used. */
+	/* First, assume absolute addressing mode is used. */
 	for (i = 0; i < 128; i++) {
 		if (*(unsigned long *) cp == addr)
 			return base + i;
@@ -798,7 +807,7 @@ static spinlock_t probe_dummy_vfsmount_lock;
  * @mnt:    Pointer to "struct vfsmount *".
  * @dentry: Pointer to "struct dentry *".
  *
- * Returns 1 if followed up, 0 otehrwise.
+ * Returns 1 if followed up, 0 otherwise.
  */
 static int probe_follow_up(struct vfsmount **mnt, struct dentry **dentry)
 {
